.. currentmodule:: sardana.tango.macroserver

:mod:`~sardana.tango.macroserver`
=================================

.. automodule:: sardana.tango.macroserver

.. rubric:: Modules

.. toctree::
    :maxdepth: 1
    
    MacroExecutor <macroserver/test/macroexecutor>
